# Nezuki

Nezuki è una libreria Python modulare per varie integrazioni come TMDB, Database, Home Assistant, Telegram e Monitoraggio Server.

## Caratteristiche

- **Database**: Gestione di database di film.
- **TMDB**: Integrazione con l'API di The Movie Database.
- **Home Assistant**: Controllo e monitoraggio dei dispositivi Home Assistant.
- **Telegram**: Invio di messaggi tramite bot Telegram.
- **Server Monitor**: Monitoraggio delle risorse del server come CPU e memoria.

## Installazione

Puoi installare Nezuki tramite pip:

```bash
pip install Nezuki
